@@ -769,8 +769,7 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 
 // WABA: Please consider using KAboutData.
 // WABA: See also KCmdLineArgs::init(...) in main(...)
-    QString about = i18n("Arts Builder ");
-	about += "0.4.0 alpha (with KDE2.0 and aRts/MCOP support)";
+    QString about = i18n("Arts Builder 0.4.0");
     about += i18n("\n\n(C) 1998-1999 Stefan Westerfeld <stefan@twc.de>\n\n"
 	       "Arts synthesizer designer.\n\n"
 		   "aRts Homepage: http://www.arts-project.org/");
@@ -793,47 +792,47 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	printf("PORT: menumaker\n");
 	menumaker = new MenuMaker(m_modules);
 	//menumaker->addCategory("&Gui","Gui_");
-	menumaker->addCategory("&Synthesis","Arts::Synth_");
-	menumaker->addCategory("&Synthesis/&Arithmetic + Mixing","Arts::Synth_ADD$");
-	menumaker->addCategory("&Synthesis/&Arithmetic + Mixing","Arts::Synth_AUTOPANNER$");
-	menumaker->addCategory("&Synthesis/&Arithmetic + Mixing","Arts::Synth_MUL$");
-	menumaker->addCategory("&Synthesis/&Arithmetic + Mixing","Arts::Synth_MULTI_ADD$");
-	menumaker->addCategory("&Synthesis/&Arithmetic + Mixing","Arts::Synth_XFADE$");
-	menumaker->addCategory("&Synthesis/&Busses","Arts::Synth_BUS_");
-	menumaker->addCategory("&Synthesis/&Delays","Arts::Synth_DELAY$");
-	menumaker->addCategory("&Synthesis/&Delays","Arts::Synth_CDELAY$");
-	menumaker->addCategory("&Synthesis/&Envelopes","Arts::Synth_PSCALE$");
-	menumaker->addCategory("&Synthesis/&Envelopes","Arts::Synth_ENVELOPE_");
-	menumaker->addCategory("&Synthesis/Effe&cts","Arts::Synth_FX_");
-	menumaker->addCategory("&Synthesis/&Filters","Arts::Synth_ATAN_SATURATE$");
-	menumaker->addCategory("&Synthesis/&Filters","Arts::Synth_MOOG_VCF");
-	menumaker->addCategory("&Synthesis/&Filters","Arts::Synth_SHELVE_CUTOFF$");
-	menumaker->addCategory("&Synthesis/&Filters","Arts::Synth_RC$");
-	menumaker->addCategory("&Synthesis/&Filters","Arts::Synth_STD_EQUALIZER$");
-	menumaker->addCategory("&Synthesis/&Midi + Sequencing","Arts::Synth_MIDI");
-	menumaker->addCategory("&Synthesis/&Midi + Sequencing","Arts::Interface_MIDI");
-	menumaker->addCategory("&Synthesis/&Midi + Sequencing","Arts::Synth_SEQUENCE$");
-	menumaker->addCategory("&Synthesis/&Midi + Sequencing","Arts::Synth_STRUCT_KILL$");
-	menumaker->addCategory("&Synthesis/Sam&ples ","Arts::Synth_PLAY_");
-	menumaker->addCategory("&Synthesis/&Sound IO","Arts::Synth_AMAN_");
-	menumaker->addCategory("&Synthesis/&Sound IO","Arts::Synth_PLAY$");
-	menumaker->addCategory("&Synthesis/&Sound IO","Arts::Synth_RECORD$");
-	menumaker->addCategory("&Synthesis/&Sound IO","Arts::Synth_FULL_DUPLEX_");
-	menumaker->addCategory("&Synthesis/&Sound IO","Arts::Synth_FILEPLAY");
-	menumaker->addCategory("&Synthesis/&Tests","Arts::Synth_NIL$");
-	menumaker->addCategory("&Synthesis/&Tests","Arts::Synth_DEBUG$");
-	menumaker->addCategory("&Synthesis/&Tests","Arts::Synth_MIDI_DEBUG$");
-	menumaker->addCategory("&Synthesis/&Oscillation & Modulation","Arts::Synth_FREQUENCY$");
-	menumaker->addCategory("&Synthesis/&Oscillation & Modulation","Arts::Synth_FM_SOURCE$");
-	menumaker->addCategory("&Synthesis/&WaveForms","Arts::Synth_WAVE_");
-	menumaker->addCategory("&Synthesis/&WaveForms","Arts::Synth_NOISE$");
-	menumaker->addCategory("&Synthesis/&Internal","Arts::Synth_PARAM_");
+	menumaker->addCategory(i18n("&Synthesis"),"Arts::Synth_");
+	menumaker->addCategory(i18n("&Synthesis/&Arithmetic + Mixing"),"Arts::Synth_ADD$");
+	menumaker->addCategory(i18n("&Synthesis/&Arithmetic + Mixing"),"Arts::Synth_AUTOPANNER$");
+	menumaker->addCategory(i18n("&Synthesis/&Arithmetic + Mixing"),"Arts::Synth_MUL$");
+	menumaker->addCategory(i18n("&Synthesis/&Arithmetic + Mixing"),"Arts::Synth_MULTI_ADD$");
+	menumaker->addCategory(i18n("&Synthesis/&Arithmetic + Mixing"),"Arts::Synth_XFADE$");
+	menumaker->addCategory(i18n("&Synthesis/&Busses"),"Arts::Synth_BUS_");
+	menumaker->addCategory(i18n("&Synthesis/&Delays"),"Arts::Synth_DELAY$");
+	menumaker->addCategory(i18n("&Synthesis/&Delays"),"Arts::Synth_CDELAY$");
+	menumaker->addCategory(i18n("&Synthesis/&Envelopes"),"Arts::Synth_PSCALE$");
+	menumaker->addCategory(i18n("&Synthesis/&Envelopes"),"Arts::Synth_ENVELOPE_");
+	menumaker->addCategory(i18n("&Synthesis/Effe&cts"),"Arts::Synth_FX_");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_ATAN_SATURATE$");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_MOOG_VCF");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_SHELVE_CUTOFF$");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_RC$");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_STD_EQUALIZER$");
+	menumaker->addCategory(i18n("&Synthesis/&Midi + Sequencing"),"Arts::Synth_MIDI");
+	menumaker->addCategory(i18n("&Synthesis/&Midi + Sequencing"),"Arts::Interface_MIDI");
+	menumaker->addCategory(i18n("&Synthesis/&Midi + Sequencing"),"Arts::Synth_SEQUENCE$");
+	menumaker->addCategory(i18n("&Synthesis/&Midi + Sequencing"),"Arts::Synth_STRUCT_KILL$");
+	menumaker->addCategory(i18n("&Synthesis/Sam&ples "),"Arts::Synth_PLAY_");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_AMAN_");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_PLAY$");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_RECORD$");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_FULL_DUPLEX_");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_FILEPLAY");
+	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_NIL$");
+	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_DEBUG$");
+	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_MIDI_DEBUG$");
+	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"),"Arts::Synth_FREQUENCY$");
+	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"),"Arts::Synth_FM_SOURCE$");
+	menumaker->addCategory(i18n("&Synthesis/&WaveForms"),"Arts::Synth_WAVE_");
+	menumaker->addCategory(i18n("&Synthesis/&WaveForms"),"Arts::Synth_NOISE$");
+	menumaker->addCategory(i18n("&Synthesis/&Internal"),"Arts::Synth_PARAM_");
 
-	menumaker->addCategory("&Examples","example_");
-	menumaker->addCategory("&Instruments","instrument_");
-	menumaker->addCategory("&Mixer-Elements","mixer_element_");
-	menumaker->addCategory("&Templates","template_");
-	menumaker->addCategory("&Other","*");
+	menumaker->addCategory(i18n("&Examples"),"example_");
+	menumaker->addCategory(i18n("&Instruments"),"instrument_");
+	menumaker->addCategory(i18n("&Mixer-Elements"),"mixer_element_");
+	menumaker->addCategory(i18n("&Templates"),"template_");
+	menumaker->addCategory(i18n("&Other"),"*");
 	printf("PORT: menumaker ok\n");
 
 /*
@@ -1234,7 +1233,7 @@ void ArtsBuilderApp::start()
 
 	printf("PORT: moduleview ok \n");
 	moduleview->resize(680,500);
-	moduleview->setCaption("Arts Builder - Module View");
+	moduleview->setCaption(i18n("Module View"));
 	printf("PORT: moduleview show \n");
 	moduleview->show();
 	printf("PORT: moduleview show ok\n");
