@@ -24,26 +24,21 @@
 #ifndef _KMIDFRAME_H
 #define _KMIDFRAME_H
 
-//#include <kapp.h>
-//#include <qwidget.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kmenubar.h>
-#include <kslider.h>
-#include "player/midiout.h"
-#include "player/player.h"
-#include "player/track.h"
-//#include <pthread/mit/pthread.h>
+#include <libkmid/midiout.h>
+#include <libkmid/player.h>
+#include <libkmid/track.h>
 #include <qtimer.h>
-//#include "kdisptext.h"
 
 class KApplication;
 class KConfig;
 class kmidClient;
 class KToolBar;
-class KDNDDropZone;
+class QDragEvent;
 class KAccel;
 
-class kmidFrame : public KTMainWindow
+class kmidFrame : public KMainWindow
 {
     Q_OBJECT
 private:
@@ -51,9 +46,9 @@ private:
     long passcount;
 #endif
 
-    midiOut *Midi;
-    player *Player;
-
+    MidiOut *Midi;
+    MidiPlayer *Player;
+/*
     int playerProcessID;
     PlayerController *pctl;
     
@@ -64,39 +59,36 @@ private:
     QPopupMenu *m_collections;
     QPopupMenu *m_options;
     QPopupMenu *m_help;
-
+*/
     KAccel *kKeysAccel;
 protected:
-    int autoAddSongToCollection(char *filename=NULL,int setactive=1);
+    int autoAddSongToCollection(const QString& filename=QString::null,int setactive=1);
 
 
     virtual void saveProperties(KConfig *kcfg);
     virtual void readProperties(KConfig *kcfg);
 
 //    virtual void closeEvent(QCloseEvent *e);
+
+    void dragEnterEvent(QDragEnterEvent* e);
+    void dropEvent ( QDropEvent * event );
+
+
 public:
     kmidFrame(const char *name=0);
     virtual ~kmidFrame();
 
-//    void readConfig(KConfig *kconf);
-
 public slots:
 
-    void buttonClicked(int i);
-    void buttonSClicked(int i);
     void file_Open();
     void file_SaveLyrics();
-    void song_Pause();
     void song_stopPause(); // release the pause button and quit the pause mode
     void song_Loop();
     void collect_organize();
-    void collect_inOrder();
-    void collect_shuffle();
-    void collect_autoadd();
-    void options_GM();
-    void options_MT32();
-    void options_Text();
-    void options_Lyrics();
+    void collect_PlayOrder(int i);
+    void collect_AutoAdd();
+    void options_FileType(int i);
+    void options_DisplayEvents(int i);
     void options_AutomaticText();
     void options_ShowVolumeBar();
     void options_ShowChannelView();
@@ -106,19 +98,35 @@ public slots:
     void options_MidiSetup();
     void spacePressed();
 
-    void slotDropEvent( KDNDDropZone * _dropZone );
- 
+
+   virtual void openURL( QString s );
+/*   virtual void play();
+   virtual void pause();
+   virtual void stop();
+   virtual void rewind();
+   virtual void forward();
+   virtual void seek(int ms);
+   virtual void prevSong();
+   virtual void nextSong();
+   virtual void setSongLoop(int i);
+   virtual void setVolume(int i);
+   virtual void setTempo(int i);
+   virtual void setSongType( int i );
+   virtual void setLyricEvents( int i );
+   virtual void selectSong(int i);
+   virtual void setActiveCollection( int i );
+   virtual void setCollectionPlayMode(int i);
+   virtual void setMidiDevice(int i);   
+*/
+    void urlDrop_slot(class QDropEvent *);
+
     void rechooseTextEvent();
 
     void channelViewDestroyed();
     void shuttingDown();
 
 private:
-    KMenuBar *menu;
     kmidClient *kmidclient;
-    KToolBar *toolbar;
-    KToolBar *toolbarSC; // toolbar for Song Collections
-    KToolBar *toolbarSong; // toolbar for Songs
 };
 
 #endif
