@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: docking.h,v 1.5 1998/12/22 05:36:19 thufir Exp $
+ * $Id: docking.h,v 1.8 1999/11/14 05:55:17 ettrich Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -29,57 +29,26 @@
 #define _DOCKING_H_
 
 #include <stdio.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qpixmap.h>
 #include <qtimer.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qpoint.h>
-
+#include <kdockwindow.h>
 
 extern int 	ibytes;
 extern int 	obytes;
 
-class DockWidget : public QWidget {
+class KSCD;
+
+class DockWidget : public KDockWindow {
 
   Q_OBJECT
 
 public:
-  DockWidget(const char *name=0);
+  DockWidget( KSCD* parent, const char *name=0);
   ~DockWidget();
 
-protected:
-  void paintEvent(QPaintEvent *e);
-
-private slots:
-    void timeclick();
-    void play_pause();
-    void forward();
-    void backward();
-    void next();
-    void prev();
-    void eject();
-    void stop();
-    void mousePressEvent(QMouseEvent *e);
-
-public slots:
-    void dock();
-    void undock();
-    void paintIcon();
-    void toggle_window_state();
-
-public:
-    const bool isDocked();
-    const bool isToggled();
-    const bool setToggled(int);
-    
-
-private:
-  bool docked;
-  int toggleID;
-  QPopupMenu *popup_m;
-  QPixmap cdsmall_pixmap;
-  bool toggled;
-
 };
 
 #endif
