@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: kscd.cpp,v 1.110 2000/10/16 08:01:07 dfoerste Exp $
+ * $Id: kscd.cpp,v 1.110.2.2 2000/10/25 04:10:45 dfoerste Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -709,7 +709,7 @@ KSCD::playClicked()
 	      {
 	      case WM_CDM_PLAYING:
                 statuslabel->setText( i18n("Pause") );
-                wm_cd_pause ();
+                wm_cd_pause();
                 break;
 	      case WM_CDM_PAUSED:
                 if(randomplay)
@@ -721,6 +721,7 @@ KSCD::playClicked()
 		  } else {
                     statuslabel->setText( i18n("Playing") );
 		  }
+                wm_cd_pause();
                 break;
 	
 	      default:
@@ -1258,7 +1259,7 @@ KSCD::randomtrack()
   /* set, the original code.  */
   if( randomonce )
     {
-      if( !playlist.isEmpty() ) 
+      if( !playlist.isEmpty() )
 	{
 	  /* Check to see if we are at the end of the list */
 	  if( (unsigned int)random_current >= playlist.count() ) 
@@ -1297,7 +1298,7 @@ KSCD::randomtrack()
       return atoi( (*playlist.at(j)).ascii() );
     } else {
       int j;
-      j = 1 + (int) randSequence.getLong(cur_ntracks);
+      j = (cur_ntracks == 0) ? 0 : (1 + (int) randSequence.getLong(cur_ntracks));
       return j;
     }
 } // randomtrack
@@ -1576,7 +1577,6 @@ KSCD::readSettings()
     mailcmd    =        config->readEntry("UnixMailCommand","/bin/mail -s \"%s\"");
     randomonce = (bool)config->readBoolEntry("RANDOMONCE",true);
 
-
 #ifdef DEFAULT_CD_DEVICE
 
     // sun ultrix etc have a canonical cd rom device specified in the
