@@ -1,7 +1,7 @@
 #ifndef WM_CONFIG_H
 #define WM_CONFIG_H
 /*
- * $Id: wm_config.h,v 1.6 2000/09/06 23:41:41 waba Exp $
+ * $Id: wm_config.h,v 1.6.2.1 2000/11/07 05:46:04 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -195,8 +195,9 @@
 
 /*
  * Linux Soundcard support
+ * Disabled by default, because some people rely on it
  */
-#define OSS_SUPPORT 1
+/*#define OSS_SUPPORT 1 */
 
 /*
  * This has nothing to do with the above.
@@ -210,8 +211,9 @@
  * drives as well. But it may be possible, that it doesn't work at all.
  * If your drive/driver combination cannot handle the faster access,
  * the driver will usually hang and you have to reboot your machine.
+ * [Defaulted this to be enabled, because KSCD-1.2.7 did it anyway.]
  */
-/* #define FAST_IDE 1 */
+#define FAST_IDE 1
 
 /*
  * There are two alternative ways of checking a device containing a
