@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: smtpconfig.cpp,v 1.3.2.1 1999/02/16 15:11:54 kulow Exp $
+ * $Id: smtpconfig.cpp,v 1.6 1999/07/02 15:13:45 bieker Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -34,18 +34,18 @@ SMTPConfig::SMTPConfig(QWidget *parent, const char *name, struct SMTPConfigData
     mainBox = new QGroupBox(this, "mainBox");
     mainBox->setGeometry(10,10,520,420);
 
-    enableCB = new QCheckBox(klocale->translate("Enable submission via SMTP"), this, "enableCB");
+    enableCB = new QCheckBox(i18n("Enable submission via SMTP"), this, "enableCB");
     enableCB->setGeometry(20, 20, 200, 15);
     enableCB->setChecked(configData->enabled);
     connect(enableCB, SIGNAL(clicked()), this, SLOT(enableClicked()));
 
     serverHostLabel = new QLabel(this, "serverHostLabel");
     serverHostLabel->setGeometry(20, 40, 130, 25);
-    serverHostLabel->setText(klocale->translate("SMTP Address:Port"));
+    serverHostLabel->setText(i18n("SMTP Address:Port"));
     
     serverHostEdit = new QLineEdit(this, "serverHostEdit");
     serverHostEdit->setGeometry(155, 40, 300, 25);
-    serverHostEdit->setText(configData->serverHost.data());
+    serverHostEdit->setText(configData->serverHost);
     serverHostEdit->setEnabled(configData->enabled);
 
     serverPortLabel = new QLabel(this, "serverPortLabel");
@@ -54,16 +54,16 @@ SMTPConfig::SMTPConfig(QWidget *parent, const char *name, struct SMTPConfigData
     
     serverPortEdit = new QLineEdit(this, "serverPortEdit");
     serverPortEdit->setGeometry(475, 40, 45, 25);
-    serverPortEdit->setText(configData->serverPort.data());
+    serverPortEdit->setText(configData->serverPort);
     serverPortEdit->setEnabled(configData->enabled);
 
     senderAddressLabel = new QLabel(this, "senderAddressLabel");
     senderAddressLabel->setGeometry(20, 70, 130, 25);
-    senderAddressLabel->setText(klocale->translate("Your Email Address"));
+    senderAddressLabel->setText(i18n("Your Email Address"));
 
     senderAddressEdit = new QLineEdit(this, "senderAddressEdit");
     senderAddressEdit->setGeometry(155, 70, 365, 25);
-    senderAddressEdit->setText(configData->senderAddress.data());
+    senderAddressEdit->setText(configData->senderAddress);
     senderAddressEdit->setEnabled(configData->enabled);
 }
 
